@@ -1,5 +1,5 @@
 /**
- * Copyright 2005-2013 The Kuali Foundation
+ * Copyright 2005-2014 The Kuali Foundation
  *
  * Licensed under the Educational Community License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -21,7 +21,7 @@ import org.junit.Test;
 /**
  * This test is currently being ignored.  See KULRICE-1852 for details.
  */
-@Ignore
+@Ignore // See KULRICE-1852 for details
 public class SimpleServiceCallNoJtaTest extends SimpleServiceCallTest {
 
 	@Test public void testAsyncJavaCall() throws Exception  {
