@@ -15,29 +15,6 @@
  */
 package org.kuali.rice.kns.util;
 
-import java.io.ByteArrayOutputStream;
-import java.io.IOException;
-import java.io.InputStream;
-import java.io.OutputStream;
-import java.util.Arrays;
-import java.util.Collection;
-import java.util.Enumeration;
-import java.util.HashMap;
-import java.util.Hashtable;
-import java.util.Iterator;
-import java.util.LinkedHashMap;
-import java.util.List;
-import java.util.Map;
-import java.util.Set;
-import java.util.regex.Matcher;
-import java.util.regex.Pattern;
-
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
-import javax.servlet.http.HttpSession;
-import javax.servlet.jsp.PageContext;
-
 import org.apache.commons.lang.StringEscapeUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.log4j.Level;
@@ -83,9 +60,36 @@ import org.kuali.rice.krad.util.KRADConstants;
 import org.kuali.rice.krad.util.MessageMap;
 import org.kuali.rice.krad.util.ObjectUtils;
 
+import javax.servlet.ServletException;
+import javax.servlet.http.HttpServletRequest;
+import javax.servlet.http.HttpServletResponse;
+import javax.servlet.http.HttpSession;
+import javax.servlet.jsp.PageContext;
+import java.io.ByteArrayOutputStream;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.OutputStream;
+import java.net.URI;
+import java.net.URISyntaxException;
+import java.util.Arrays;
+import java.util.Collection;
+import java.util.Enumeration;
+import java.util.HashMap;
+import java.util.Hashtable;
+import java.util.Iterator;
+import java.util.LinkedHashMap;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
+
 /**
  * General helper methods for handling requests.
+ *
+ * @deprecated Only used in KNS classes, use KRAD.
  */
+@Deprecated
 public class WebUtils {
 	private static final Logger LOG = Logger.getLogger(WebUtils.class);
 
@@ -951,11 +955,20 @@ public class WebUtils {
         }
         return base + path;
     }
-
+    
     public static String sanitizeBackLocation(String backLocation) {
         if(StringUtils.isBlank(backLocation)) {
             return backLocation;
         }
+		// if it's a relative URL then we should be good regardless
+		try {
+			URI uri = new URI(backLocation);
+			if (!uri.isAbsolute()) {
+				return backLocation;
+			}
+		} catch (URISyntaxException e) {
+			// move on to the other checks if it doesn't parse up as a URI for some reason
+		}
         Pattern pattern = Pattern.compile(ConfigContext.getCurrentContextConfig().getProperty(KRADConstants.BACK_LOCATION_ALLOWED_REGEX));
         if(pattern.matcher(backLocation).matches()) {
             return backLocation;
@@ -963,4 +976,5 @@ public class WebUtils {
             return ConfigContext.getCurrentContextConfig().getProperty(KRADConstants.BACK_LOCATION_DEFAULT_URL);
         }
     }
+
 }
