@@ -21,7 +21,7 @@ import java.util.List;
 import org.kuali.rice.core.api.CoreConstants;
 
 /**
- * Defines Global Constants for the KRAD Module
+ * Defines Global Constants for the KRAD Module.
  *
  * @author Kuali Rice Team (rice.collab@kuali.org)
  */
@@ -44,8 +44,8 @@ public final class KRADConstants {
     public static final String KRAD_INQUIRY_URL_KEY = "krad.inquiry.url";
     public static final String KRAD_LOOKUP_URL_KEY = "krad.lookup.url";
     public static final String KRAD_SERVER_LOOKUP_URL_KEY = "rice.server.krad.lookup.url";
-    public static final String KRAD_INITIATED_DOCUMENT_URL_KEY="initiated.document.url";
-    public static final String KRAD_INITIATED_DOCUMENT_VIEW_NAME="InitiatedDocumentView";
+    public static final String KRAD_INITIATED_DOCUMENT_URL_KEY = "initiated.document.url";
+    public static final String KRAD_INITIATED_DOCUMENT_VIEW_NAME = "InitiatedDocumentView";
 
     public static final String KRAD_DICTIONARY_INDEX_POOL_SIZE = "krad.dictionary.indexPoolSize";
 
@@ -82,6 +82,9 @@ public final class KRADConstants {
     public static final String KUALI_ACTION_CAN_SEND_NOTE_FYI = "canSendNoteFyi";
     public static final String KUALI_ACTION_CAN_EDIT_DOCUMENT_OVERVIEW = "canEditDocumentOverview";
     public static final String KUALI_ACTION_CAN_EXPORT = "canExport";
+    public static final String KUALI_ACTION_CAN_SUPER_USER_TAKE_ACTION = "canSuperUserTakeAction";
+    public static final String KUALI_ACTION_CAN_SUPER_USER_APPROVE = "canSuperUserApprove";
+    public static final String KUALI_ACTION_CAN_SUPER_USER_DISAPPROVE = "canSuperUserDisapprove";
     public static final String KUALI_DEFAULT_TRUE_VALUE = "true";
     public static final String USE_CACHE_ADMINISTRATION_SCREEN = "Use Cache Adminstration Screen";
     public static final String KUALI_ACTION_CAN_COMPLETE = "canComplete";
@@ -109,7 +112,6 @@ public final class KRADConstants {
         public static final String RULE_SERVICE_DETAIL_TYPE = "RuleBaseValues";
         public static final String RULE_TEMPLATE_DETAIL_TYPE = "RuleTemplate";
         public static final String WORKGROUP_DETAIL_TYPE = "Notification";
-
         private DetailTypes() {
             throw new UnsupportedOperationException("do not call");
         }
@@ -446,6 +448,8 @@ public final class KRADConstants {
     public static final String QUESTION_TEXT_ATTRIBUTE_NAME = "questionText";
     public static final String QUESTION_REASON_ATTRIBUTE_NAME = "reason";
     public static final String QUESTION_SHOW_REASON_FIELD = "showReasonField";
+    public static final String QUESTION_ACTION_RECALL_REASON = "ConfirmRecallDialog";
+    public static final String QUESTION_ACTION_CLOSE_RESPONSE = "ConfirmSaveOnCloseDialog";
 
     public static final String REFRESH_CALLER = "refreshCaller";
     public static final String REFRESH_CALLER_TYPE = "refreshCallerType";
@@ -481,6 +485,10 @@ public final class KRADConstants {
     public static final String BO_ATTACHMENT_FILE_CONTENT_TYPE = "contentType";
     public static final String BO_ATTACHMENT_FILE_CONTENT_FIELD = "fileContentBOField";
 
+    public static final String DATA_OBJECT_ATTACHMENT_FILE_NAME = "fileName";
+    public static final String DATA_OBJECT_ATTACHMENT_FILE_CONTENT_TYPE = "contentType";
+    public static final String DATA_OBJECT_ATTACHMENT_FILE_CONTENT_FIELD = "fileContentDataObjectField";
+
     // specialized method 'delete' used only for PessimisticLocks currently
     public static final String DELETE_METHOD = "delete";
     public static final String START_METHOD = "start";
@@ -529,6 +537,8 @@ public final class KRADConstants {
     public static final String CSV_FORMAT = "csv";
 
     public static final String XML_MIME_TYPE = "application/xml";
+    public static final String EXCEL_MIME_TYPE = "application/vnd.ms-excel";
+    public static final String CSV_MIME_TYPE = "text/csv";
 
     // Header Tab navigation constant values
     public static final String NAVIGATE_TO = "navigateTo.";
@@ -551,9 +561,12 @@ public final class KRADConstants {
         public static final String CHECK_ENCRYPTION_SERVICE_OVERRIDE_IND = "CHECK_ENCRYPTION_SERVICE_OVERRIDE_IND";
 
         public static final String LOOKUP_RESULTS_LIMIT = "RESULTS_LIMIT";
+        public static final String MULTIPLE_VALUE_LOOKUP_RESULTS_LIMIT = "MULTIPLE_VALUE_RESULTS_LIMIT";
         public static final String MULTIPLE_VALUE_LOOKUP_RESULTS_PER_PAGE = "MULTIPLE_VALUE_RESULTS_PER_PAGE";
         //        public static final String MULTIPLE_VALUE_LOOKUP_RESULTS_EXPIRATION_AGE = "MULTIPLE_VALUE_RESULTS_EXPIRATION_SECONDS";
 
+        public static final String  AUTO_TRUNCATE_COLUMNS = "AUTO_TRUNCATE_COLUMNS";
+
         public static final String DEFAULT_CAN_PERFORM_ROUTE_REPORT_IND = "DEFAULT_CAN_PERFORM_ROUTE_REPORT_IND";
         public static final String ALLOW_ENROUTE_BLANKET_APPROVE_WITHOUT_APPROVAL_REQUEST_IND =
                 "ALLOW_ENROUTE_BLANKET_APPROVE_WITHOUT_APPROVAL_REQUEST_IND";
@@ -571,7 +584,6 @@ public final class KRADConstants {
         //        public static final String PURGE_PENDING_ATTACHMENTS_STEP_MAX_AGE = "purgePendingAttachmentsStepMaxAge";
 
         public static final String ENABLE_DIRECT_INQUIRIES_IND = "ENABLE_DIRECT_INQUIRIES_IND";
-        public static final String DEFAULT_COUNTRY = "DEFAULT_COUNTRY";
 
         public static final String SENSITIVE_DATA_PATTERNS = "SENSITIVE_DATA_PATTERNS";
         public static final String SENSITIVE_DATA_PATTERNS_WARNING_IND = "SENSITIVE_DATA_PATTERNS_WARNING_IND";
@@ -624,7 +636,11 @@ public final class KRADConstants {
         public static final String ILLEGAL_BUSINESS_OBJECTS_FOR_SAVE = "rice.krad.illegalBusinessObjectsForSave";
         public static final String COMPONENT_PUBLISHING_ENABLED = "rice.krad.componentPublishing.enabled";
         public static final String COMPONENT_PUBLISHING_DELAY = "rice.krad.componentPublishing.delay";
-        public static final String IGNORE_MISSIONG_FIELDS_ON_DESERIALIZE = "rice.krad.bos.ignoreMissingFieldsOnDeserialize";
+        public static final String IGNORE_MISSIONG_FIELDS_ON_DESERIALIZE =
+                "rice.krad.bos.ignoreMissingFieldsOnDeserialize";
+        public static final String KNS_ENABLED = "rice.krad.kns.enabled";
+        public static final String ENABLE_LEGACY_DATA_FRAMEWORK = "rice.krad.enableLegacyDataFramework";
+        public static final String ENABLE_VIEW_AUTOGENERATION = "rice.krad.views.autoGeneration.enabled";
 
         private Config() {
             throw new UnsupportedOperationException("do not call");
@@ -659,9 +675,15 @@ public final class KRADConstants {
         public static final String LOCK_AFTER_VALUE_DELIM = "::";
     }
 
+    public static final class Document {
+        public static final String METHOD_TO_CALL_COPY = "copy";
+    }
+
     public static class Lookup {
         public static final String TITLE_RETURN_URL_PREPENDTEXT_PROPERTY = "title.return.url.value.prependtext";
         public static final String TITLE_ACTION_URL_PREPENDTEXT_PROPERTY = "title.action.url.value.prependtext";
+        //KULRICE-12281:Turn off the ability to export results from the person lookup
+        public static final String VIEW_RESULTS_EXPORT_OPTION = "d-16544-e";
     }
 
     public static final class MessageParsing {
@@ -698,5 +720,28 @@ public final class KRADConstants {
         public static final String APPLICATION_VERSION = "application.version";
         public static final String APPLICATION_URL = "application.url";
         public static final String KRAD_DEV_MODE = "rice.krad.dev.mode";
+        public static final String KRAD_SCRIPT_CLEANUP = "rice.krad.script.cleanup";
+        public static final String KRAD_STRICT_LIFECYCLE = "rice.krad.lifecycle.strict";
+        public static final String KRAD_VIEW_LIFECYCLE_TRACE = "rice.krad.lifecycle.trace";
+        public static final String KRAD_RENDER_IN_LIFECYCLE = "rice.krad.lifecycle.render";
+        public static final String KRAD_VIEW_LIFECYCLE_ASYNCHRONOUS = "rice.krad.lifecycle.asynchronous";
+        public static final String KRAD_VIEW_LIFECYCLE_MINTHREADS = "rice.krad.lifecycle.asynchronous.minThreads";
+        public static final String KRAD_VIEW_LIFECYCLE_MAXTHREADS = "rice.krad.lifecycle.asynchronous.maxThreads";
+        public static final String KRAD_VIEW_LIFECYCLE_TIMEOUT = "rice.krad.lifecycle.asynchronous.timeout";
+        public static final String KRAD_COPY_DELAY = "rice.krad.copyable.delay";
+        public static final String KRAD_INCLUDE_LESS = "rice.krad.include.less";
+        public static final String SCHEMA_PACKAGES = "rice.krad.schema.packages";
+    }
+
+    public static final class ControllerMappings {
+        public static final String INIT_DOC_INFO = "initdocinfo";
+        public static final String INQUIRY = "/inquiry";
+        public static final String LOOKUP = "/lookup";
+        public static final String MAINTENANCE = "/maintenance";
+    }
+
+    public static final class Audit {
+        public static final String AUDIT_ERRORS = "Error";
+        public static final String AUDIT_WARNINGS = "Warnings";
     }
 }
