@@ -15,7 +15,6 @@
  */
 package org.kuali.rice.krad.uif.util;
 
-import com.google.common.collect.Lists;
 import org.apache.commons.lang.StringUtils;
 import org.kuali.rice.krad.datadictionary.parse.BeanTag;
 import org.kuali.rice.krad.datadictionary.parse.BeanTagAttribute;
@@ -25,7 +24,9 @@ import org.kuali.rice.krad.service.KRADServiceLocatorWeb;
 import org.kuali.rice.krad.uif.UifConstants;
 import org.kuali.rice.krad.uif.component.Component;
 import org.kuali.rice.krad.uif.container.PageGroup;
+import org.kuali.rice.krad.uif.element.BreadcrumbItem;
 import org.kuali.rice.krad.uif.element.Header;
+import org.kuali.rice.krad.uif.lifecycle.ViewLifecycle;
 import org.kuali.rice.krad.uif.view.ExpressionEvaluator;
 import org.kuali.rice.krad.uif.view.View;
 
@@ -39,8 +40,7 @@ import java.util.Map;
  * View.  Essentially, this class provides a way to determine a conceptual hierarchy of view/page locations.
  * This information is used internally to generate BreadcrumbItems that can appear before the View's breadcrumbs.
  */
-@BeanTags({@BeanTag(name = "parentLocation-bean", parent = "Uif-ParentLocation"),
-        @BeanTag(name = "ricePortalParentLocation", parent = "Uif-RicePortalParentLocation")})
+@BeanTag(name = "parentLocation", parent = "Uif-ParentLocation")
 public class ParentLocation extends UifDictionaryBeanBase implements Serializable {
 
     private static final long serialVersionUID = -6242148809697931126L;
@@ -74,8 +74,7 @@ public class ParentLocation extends UifDictionaryBeanBase implements Serializabl
         }
 
         //evaluate expressions on relevant content before comparisons
-        this.handleExpressions(view, currentModel, currentContext,
-                view.getViewHelperService().getExpressionEvaluator());
+        this.handleExpressions(view, currentModel, currentContext, ViewLifecycle.getExpressionEvaluator());
 
         //set url values into breadcrumb objects
         if (StringUtils.isNotBlank(parentViewUrl.getOriginalHref()) || (StringUtils.isNotBlank(
@@ -138,7 +137,7 @@ public class ParentLocation extends UifDictionaryBeanBase implements Serializabl
     private void processParentViewDerivedContent(View parentView, String parentViewId, View currentView,
             Object currentModel, Map<String, Object> currentContext) {
         //populate expression graph
-        ExpressionUtils.populatePropertyExpressionsFromGraph(parentView, false);
+        ViewLifecycle.getExpressionEvaluator().populatePropertyExpressionsFromGraph(parentView, false);
 
         //chain parent locations if not null on parent
         if (((View) parentView).getParentLocation() != null) {
@@ -147,8 +146,7 @@ public class ParentLocation extends UifDictionaryBeanBase implements Serializabl
                             currentModel, currentContext));
         }
 
-        handleLabelExpressions(parentView, currentModel, currentContext,
-                currentView.getViewHelperService().getExpressionEvaluator());
+        handleLabelExpressions(parentView, currentModel, currentContext, ViewLifecycle.getExpressionEvaluator());
 
         //label automation, if parent has a label for its breadcrumb and one is not set here use that value
         //it is assumed that if the label contains a SpringEL expression, those properties are available on the
@@ -165,7 +163,6 @@ public class ParentLocation extends UifDictionaryBeanBase implements Serializabl
         if (parentView.getBreadcrumbItem() != null
                 && parentView.getBreadcrumbItem().getSiblingBreadcrumbComponent() != null
                 && viewBreadcrumbItem.getSiblingBreadcrumbComponent() == null) {
-            currentView.assignComponentIds(parentView.getBreadcrumbItem().getSiblingBreadcrumbComponent());
             viewBreadcrumbItem.setSiblingBreadcrumbComponent(
                     parentView.getBreadcrumbItem().getSiblingBreadcrumbComponent());
         }
@@ -205,8 +202,7 @@ public class ParentLocation extends UifDictionaryBeanBase implements Serializabl
             BreadcrumbItem breadcrumbItem = parentView.getBreadcrumbItem();
 
             if (breadcrumbItem != null) {
-                expressionEvaluator.evaluateExpressionsOnConfigurable(parentView, breadcrumbItem,
-                        currentContext);
+                expressionEvaluator.evaluateExpressionsOnConfigurable(parentView, breadcrumbItem, currentContext);
             }
 
             if (pageBreadcrumbItem != null && pageBreadcrumbItem.getUrl() != null && StringUtils.isNotBlank(
@@ -229,7 +225,7 @@ public class ParentLocation extends UifDictionaryBeanBase implements Serializabl
                 }
 
                 //populate from expression graph
-                ExpressionUtils.populatePropertyExpressionsFromGraph(thePage, false);
+                ViewLifecycle.getExpressionEvaluator().populatePropertyExpressionsFromGraph(thePage, false);
 
                 Header pageHeader = thePage.getHeader();
 
@@ -240,15 +236,13 @@ public class ParentLocation extends UifDictionaryBeanBase implements Serializabl
                                 thePage.getPropertyExpressions().get(UifConstants.ComponentProperties.HEADER_TEXT));
                     }
 
-                    expressionEvaluator.evaluateExpressionsOnConfigurable(parentView, pageHeader,
-                            currentContext);
+                    expressionEvaluator.evaluateExpressionsOnConfigurable(parentView, pageHeader, currentContext);
                 }
 
                 BreadcrumbItem pageBreadcrumb = thePage.getBreadcrumbItem();
 
                 if (pageBreadcrumb != null) {
-                    expressionEvaluator.evaluateExpressionsOnConfigurable(parentView, pageBreadcrumb,
-                            currentContext);
+                    expressionEvaluator.evaluateExpressionsOnConfigurable(parentView, pageBreadcrumb, currentContext);
                 }
             }
         } catch (RuntimeException e) {
@@ -344,8 +338,6 @@ public class ParentLocation extends UifDictionaryBeanBase implements Serializabl
         if (thePage.getBreadcrumbItem() != null
                 && thePage.getBreadcrumbItem().getSiblingBreadcrumbComponent() != null
                 && pageBreadcrumbItem.getSiblingBreadcrumbComponent() == null) {
-            view.assignComponentIds(thePage.getBreadcrumbItem().getSiblingBreadcrumbComponent());
-
             pageBreadcrumbItem.setSiblingBreadcrumbComponent(
                     thePage.getBreadcrumbItem().getSiblingBreadcrumbComponent());
         }
@@ -507,39 +499,4 @@ public class ParentLocation extends UifDictionaryBeanBase implements Serializabl
         return resolvedBreadcrumbItems;
     }
 
-    /**
-     * Copies properties for parent location
-     *
-     * @param parentLocation to copy properties to
-     */
-    protected <T> void copyProperties(T parentLocation) {
-        ParentLocation parentLocationCopy = (ParentLocation) parentLocation;
-
-        if (this.parentViewUrl != null) {
-            parentLocationCopy.setParentViewUrl((UrlInfo) this.parentViewUrl.copy());
-        }
-
-        if (this.parentPageUrl != null) {
-            parentLocationCopy.setParentPageUrl((UrlInfo) this.parentPageUrl.copy());
-        }
-
-        parentLocationCopy.setParentViewLabel(this.parentViewLabel);
-        parentLocationCopy.setParentPageLabel(this.parentPageLabel);
-
-        if (this.viewBreadcrumbItem != null) {
-            parentLocationCopy.setViewBreadcrumbItem((BreadcrumbItem) this.viewBreadcrumbItem.copy());
-        }
-
-        if (this.pageBreadcrumbItem != null) {
-            parentLocationCopy.setPageBreadcrumbItem((BreadcrumbItem) this.pageBreadcrumbItem.copy());
-        }
-
-        if (this.resolvedBreadcrumbItems != null) {
-            List<BreadcrumbItem> resolvedBreadcrumbItemsCopy = new ArrayList<BreadcrumbItem>();
-            for (BreadcrumbItem resolvedBreadcrumb : this.resolvedBreadcrumbItems) {
-                resolvedBreadcrumbItemsCopy.add((BreadcrumbItem) resolvedBreadcrumb.copy());
-            }
-            parentLocationCopy.resolvedBreadcrumbItems = resolvedBreadcrumbItemsCopy;
-        }
-    }
 }
