@@ -31,7 +31,9 @@ import org.kuali.rice.krad.uif.container.CollectionGroup;
 import org.kuali.rice.krad.uif.container.Group;
 import org.kuali.rice.krad.uif.element.Action;
 import org.kuali.rice.krad.uif.field.DataField;
+import org.kuali.rice.krad.uif.field.DataFieldSecurity;
 import org.kuali.rice.krad.uif.field.Field;
+import org.kuali.rice.krad.uif.field.FieldSecurity;
 import org.kuali.rice.krad.uif.util.ObjectPropertyUtils;
 import org.kuali.rice.krad.uif.widget.Widget;
 import org.kuali.rice.krad.util.KRADConstants;
@@ -54,13 +56,15 @@ import java.util.Set;
  *
  * @author Kuali Rice Team (rice.collab@kuali.org)
  */
-@BeanTag(name = "viewAuthorizer-bean")
+@BeanTag(name = "viewAuthorizer")
 public class ViewAuthorizerBase extends DataObjectAuthorizerBase implements ViewAuthorizer {
     private static final long serialVersionUID = -2687378084630965412L;
     private static final org.apache.log4j.Logger LOG = org.apache.log4j.Logger.getLogger(ViewAuthorizerBase.class);
 
     private ConfigurationService configurationService;
 
+    private RequestAuthorizationCache requestAuthorizationCache;
+
     /**
      * @see ViewAuthorizer#getActionFlags(org.kuali.rice.krad.uif.view.View, org.kuali.rice.krad.uif.view.ViewModel,
      *      org.kuali.rice.kim.api.identity.Person, java.util.Set<java.lang.String>)
@@ -82,15 +86,20 @@ public class ViewAuthorizerBase extends DataObjectAuthorizerBase implements View
 
         Object dataObjectForContext = getDataObjectContext(view, model);
 
+        // loop through supplied editModes and make sure KIM permission exists
         for (String editMode : editModes) {
             Map<String, String> additionalPermissionDetails = new HashMap<String, String>();
             additionalPermissionDetails.put(KimConstants.AttributeConstants.EDIT_MODE, editMode);
-            if (permissionExistsByTemplate(dataObjectForContext, KRADConstants.KNS_NAMESPACE,
-                    KimConstants.PermissionTemplateNames.USE_TRANSACTIONAL_DOCUMENT, additionalPermissionDetails)
-                    && !isAuthorizedByTemplate(dataObjectForContext, KRADConstants.KNS_NAMESPACE,
-                    KimConstants.PermissionTemplateNames.USE_TRANSACTIONAL_DOCUMENT, user.getPrincipalId(),
-                    additionalPermissionDetails, null)) {
-                unauthorizedEditModes.add(editMode);
+            additionalPermissionDetails.put(KimConstants.AttributeConstants.VIEW_ID, view.getId());
+            boolean exists = permissionExistsByTemplate(dataObjectForContext, KRADConstants.KRAD_NAMESPACE,
+                    KimConstants.PermissionTemplateNames.USE_VIEW, additionalPermissionDetails);
+            if (exists) {
+                boolean authorized = isAuthorizedByTemplate(dataObjectForContext, KRADConstants.KRAD_NAMESPACE,
+                        KimConstants.PermissionTemplateNames.USE_VIEW, user.getPrincipalId(),
+                        additionalPermissionDetails, null);
+                if (!authorized) {
+                    unauthorizedEditModes.add(editMode);
+                }
             }
         }
         editModes.removeAll(unauthorizedEditModes);
@@ -144,6 +153,10 @@ public class ViewAuthorizerBase extends DataObjectAuthorizerBase implements View
      * org.kuali.rice.krad.uif.field.DataField, java.lang.String, org.kuali.rice.kim.api.identity.Person)
      */
     public boolean canUnmaskField(View view, ViewModel model, DataField field, String propertyName, Person user) {
+        if (field.getDataFieldSecurity() == null) {
+            return true;
+        }
+
         // check mask authz flag is set
         AttributeSecurity attributeSecurity = field.getDataFieldSecurity().getAttributeSecurity();
         if (attributeSecurity == null || !attributeSecurity.isMask()) {
@@ -182,6 +195,10 @@ public class ViewAuthorizerBase extends DataObjectAuthorizerBase implements View
      */
     public boolean canPartialUnmaskField(View view, ViewModel model, DataField field, String propertyName,
             Person user) {
+        if (field.getDataFieldSecurity() == null) {
+            return true;
+        }
+
         // check partial mask authz flag is set
         AttributeSecurity attributeSecurity = field.getDataFieldSecurity().getAttributeSecurity();
         if (attributeSecurity == null || !attributeSecurity.isPartialMask()) {
@@ -219,8 +236,20 @@ public class ViewAuthorizerBase extends DataObjectAuthorizerBase implements View
      * org.kuali.rice.krad.uif.field.Field, java.lang.String, org.kuali.rice.kim.api.identity.Person)
      */
     public boolean canEditField(View view, ViewModel model, Field field, String propertyName, Person user) {
-        // check edit authz flag is set
-        if (!field.getComponentSecurity().isEditAuthz()) {
+        ComponentSecurity componentSecurity = field.getComponentSecurity();
+
+        // check component security exists
+        if (componentSecurity == null) {
+            return true;
+        }
+
+        // first check hide flag is set (lower precedence)
+        if (componentSecurity.isEditAuthz() == null && !isDataFieldAttributeSecurityHide(field)) {
+            return true;
+        }
+
+        // then check edit authz is set (higher precedence)
+        if (componentSecurity.isEditAuthz() != null && !componentSecurity.isEditAuthz().booleanValue()) {
             return true;
         }
 
@@ -233,8 +262,20 @@ public class ViewAuthorizerBase extends DataObjectAuthorizerBase implements View
      * org.kuali.rice.krad.uif.field.Field, java.lang.String, org.kuali.rice.kim.api.identity.Person)
      */
     public boolean canViewField(View view, ViewModel model, Field field, String propertyName, Person user) {
-        // check view authz flag is set
-        if (!field.getComponentSecurity().isViewAuthz()) {
+        ComponentSecurity componentSecurity = field.getComponentSecurity();
+
+        // check component security exists
+        if (componentSecurity == null) {
+            return true;
+        }
+
+        // first check hide flag is set (lower precedence)
+        if (componentSecurity.isViewAuthz() == null && !isDataFieldAttributeSecurityHide(field)) {
+            return true;
+        }
+
+        // then check view authz is set (higher precedence)
+        if (componentSecurity.isViewAuthz() != null && !componentSecurity.isViewAuthz().booleanValue()) {
             return true;
         }
 
@@ -247,8 +288,15 @@ public class ViewAuthorizerBase extends DataObjectAuthorizerBase implements View
      * org.kuali.rice.krad.uif.container.Group, java.lang.String, org.kuali.rice.kim.api.identity.Person)
      */
     public boolean canEditGroup(View view, ViewModel model, Group group, String groupId, Person user) {
+        ComponentSecurity componentSecurity = group.getComponentSecurity();
+
+        // check component security exists
+        if (componentSecurity == null) {
+            return true;
+        }
+
         // check edit group authz flag is set
-        if (!group.getComponentSecurity().isEditAuthz()) {
+        if (componentSecurity.isEditAuthz() == null || !componentSecurity.isEditAuthz().booleanValue()) {
             return true;
         }
 
@@ -261,8 +309,15 @@ public class ViewAuthorizerBase extends DataObjectAuthorizerBase implements View
      * org.kuali.rice.krad.uif.container.Group, java.lang.String, org.kuali.rice.kim.api.identity.Person)
      */
     public boolean canViewGroup(View view, ViewModel model, Group group, String groupId, Person user) {
+        ComponentSecurity componentSecurity = group.getComponentSecurity();
+
+        // check component security exists
+        if (componentSecurity == null) {
+            return true;
+        }
+
         // check view group authz flag is set
-        if (!group.getComponentSecurity().isViewAuthz()) {
+        if (componentSecurity.isViewAuthz() == null || !componentSecurity.isViewAuthz().booleanValue()) {
             return true;
         }
 
@@ -275,8 +330,15 @@ public class ViewAuthorizerBase extends DataObjectAuthorizerBase implements View
      * org.kuali.rice.krad.uif.widget.Widget, java.lang.String, org.kuali.rice.kim.api.identity.Person)
      */
     public boolean canEditWidget(View view, ViewModel model, Widget widget, String widgetId, Person user) {
+        ComponentSecurity componentSecurity = widget.getComponentSecurity();
+
+        // check component security exists
+        if (componentSecurity == null) {
+            return true;
+        }
+
         // check edit widget authz flag is set
-        if (!widget.getComponentSecurity().isViewAuthz()) {
+        if (componentSecurity.isEditAuthz() == null || !componentSecurity.isEditAuthz().booleanValue()) {
             return true;
         }
 
@@ -289,8 +351,15 @@ public class ViewAuthorizerBase extends DataObjectAuthorizerBase implements View
      * org.kuali.rice.krad.uif.widget.Widget, java.lang.String, org.kuali.rice.kim.api.identity.Person)
      */
     public boolean canViewWidget(View view, ViewModel model, Widget widget, String widgetId, Person user) {
+        ComponentSecurity componentSecurity = widget.getComponentSecurity();
+
+        // check component security exists
+        if (componentSecurity == null) {
+            return true;
+        }
+
         // check view widget authz flag is set
-        if (!widget.getComponentSecurity().isViewAuthz()) {
+        if (componentSecurity.isViewAuthz() == null || !componentSecurity.isViewAuthz().booleanValue()) {
             return true;
         }
 
@@ -305,7 +374,7 @@ public class ViewAuthorizerBase extends DataObjectAuthorizerBase implements View
     public boolean canPerformAction(View view, ViewModel model, Action action, String actionEvent,
             String actionId, Person user) {
         // check action authz flag is set
-        if (!action.getActionSecurity().isPerformActionAuthz()) {
+        if ((action.getActionSecurity() == null) || !action.getActionSecurity().isPerformActionAuthz()) {
             return true;
         }
 
@@ -321,7 +390,8 @@ public class ViewAuthorizerBase extends DataObjectAuthorizerBase implements View
     public boolean canEditLine(View view, ViewModel model, CollectionGroup collectionGroup,
             String collectionPropertyName, Object line, Person user) {
         // check edit line authz flag is set
-        if (!collectionGroup.getCollectionGroupSecurity().isEditLineAuthz()) {
+        if ((collectionGroup.getCollectionGroupSecurity() == null) || !collectionGroup.getCollectionGroupSecurity()
+                .isEditLineAuthz()) {
             return true;
         }
 
@@ -332,7 +402,8 @@ public class ViewAuthorizerBase extends DataObjectAuthorizerBase implements View
     public boolean canViewLine(View view, ViewModel model, CollectionGroup collectionGroup,
             String collectionPropertyName, Object line, Person user) {
         // check view line authz flag is set
-        if (!collectionGroup.getCollectionGroupSecurity().isViewLineAuthz()) {
+        if ((collectionGroup.getCollectionGroupSecurity() == null) || !collectionGroup.getCollectionGroupSecurity()
+                .isViewLineAuthz()) {
             return true;
         }
 
@@ -342,8 +413,20 @@ public class ViewAuthorizerBase extends DataObjectAuthorizerBase implements View
 
     public boolean canEditLineField(View view, ViewModel model, CollectionGroup collectionGroup,
             String collectionPropertyName, Object line, Field field, String propertyName, Person user) {
-        // check edit line field authz flag is set
-        if (!field.getFieldSecurity().isEditInLineAuthz()) {
+        FieldSecurity fieldSecurity = field.getFieldSecurity();
+
+        // check field security exists
+        if (fieldSecurity == null) {
+            return true;
+        }
+
+        // first check hide flag is set (lower precedence)
+        if (fieldSecurity.isEditInLineAuthz() == null && !isDataFieldAttributeSecurityHide(field)) {
+            return true;
+        }
+
+        // then check edit line field authz flag is set (higher precedence)
+        if (fieldSecurity.isEditInLineAuthz() != null && !fieldSecurity.isEditInLineAuthz().booleanValue()) {
             return true;
         }
 
@@ -358,8 +441,20 @@ public class ViewAuthorizerBase extends DataObjectAuthorizerBase implements View
 
     public boolean canViewLineField(View view, ViewModel model, CollectionGroup collectionGroup,
             String collectionPropertyName, Object line, Field field, String propertyName, Person user) {
-        // check view line field authz flag is set
-        if (!field.getFieldSecurity().isViewInLineAuthz()) {
+        FieldSecurity fieldSecurity = field.getFieldSecurity();
+
+        // check field security exists
+        if (fieldSecurity == null) {
+            return true;
+        }
+
+        // first check hide flag is set (lower precedence)
+        if (fieldSecurity.isViewInLineAuthz() == null && !isDataFieldAttributeSecurityHide(field)) {
+            return true;
+        }
+
+        // then check view line field authz flag is set (higher precedence)
+        if (fieldSecurity.isViewInLineAuthz() != null && !fieldSecurity.isViewInLineAuthz().booleanValue()) {
             return true;
         }
 
@@ -376,7 +471,7 @@ public class ViewAuthorizerBase extends DataObjectAuthorizerBase implements View
             String collectionPropertyName, Object line, Action action, String actionEvent, String actionId,
             Person user) {
         // check perform line action authz flag is set
-        if (!action.getActionSecurity().isPerformLineActionAuthz()) {
+        if ((action.getActionSecurity() == null) || !action.getActionSecurity().isPerformLineActionAuthz()) {
             return true;
         }
 
@@ -556,30 +651,35 @@ public class ViewAuthorizerBase extends DataObjectAuthorizerBase implements View
         ComponentSecurity componentSecurity = component.getComponentSecurity();
 
         // add configured overrides
-        if (StringUtils.isNotBlank(componentSecurity.getNamespaceAttribute())) {
-            permissionDetails.put(KimConstants.AttributeConstants.NAMESPACE_CODE,
-                    componentSecurity.getNamespaceAttribute());
-        }
-        if (StringUtils.isNotBlank(componentSecurity.getComponentAttribute())) {
-            permissionDetails.put(KimConstants.AttributeConstants.COMPONENT_NAME,
-                    componentSecurity.getComponentAttribute());
-        }
-        if (StringUtils.isNotBlank(componentSecurity.getIdAttribute())) {
-            if (component instanceof Field) {
-                permissionDetails.put(KimConstants.AttributeConstants.FIELD_ID, componentSecurity.getIdAttribute());
-            } else if (component instanceof Group) {
-                permissionDetails.put(KimConstants.AttributeConstants.GROUP_ID, componentSecurity.getIdAttribute());
-            } else if (component instanceof Widget) {
-                permissionDetails.put(KimConstants.AttributeConstants.WIDGET_ID, componentSecurity.getIdAttribute());
+        if (componentSecurity != null) {
+            if (StringUtils.isNotBlank(componentSecurity.getNamespaceAttribute())) {
+                permissionDetails.put(KimConstants.AttributeConstants.NAMESPACE_CODE,
+                        componentSecurity.getNamespaceAttribute());
             }
-        }
 
-        if (componentSecurity.getAdditionalPermissionDetails() != null) {
-            permissionDetails.putAll(componentSecurity.getAdditionalPermissionDetails());
-        }
+            if (StringUtils.isNotBlank(componentSecurity.getComponentAttribute())) {
+                permissionDetails.put(KimConstants.AttributeConstants.COMPONENT_NAME,
+                        componentSecurity.getComponentAttribute());
+            }
 
-        if (componentSecurity.getAdditionalRoleQualifiers() != null) {
-            roleQualifications.putAll(componentSecurity.getAdditionalRoleQualifiers());
+            if (StringUtils.isNotBlank(componentSecurity.getIdAttribute())) {
+                if (component instanceof Field) {
+                    permissionDetails.put(KimConstants.AttributeConstants.FIELD_ID, componentSecurity.getIdAttribute());
+                } else if (component instanceof Group) {
+                    permissionDetails.put(KimConstants.AttributeConstants.GROUP_ID, componentSecurity.getIdAttribute());
+                } else if (component instanceof Widget) {
+                    permissionDetails.put(KimConstants.AttributeConstants.WIDGET_ID,
+                            componentSecurity.getIdAttribute());
+                }
+            }
+
+            if (componentSecurity.getAdditionalPermissionDetails() != null) {
+                permissionDetails.putAll(componentSecurity.getAdditionalPermissionDetails());
+            }
+
+            if (componentSecurity.getAdditionalRoleQualifiers() != null) {
+                roleQualifications.putAll(componentSecurity.getAdditionalRoleQualifiers());
+            }
         }
 
         boolean result = true;
@@ -607,6 +707,33 @@ public class ViewAuthorizerBase extends DataObjectAuthorizerBase implements View
                 && !getConfigurationService().getPropertyValueAsBoolean(KRADConstants.ENABLE_NONPRODUCTION_UNMASKING);
     }
 
+    /**
+     * Determines whether {@code AttributeSecurity} is set on the {@code DataField} and if it is, whether its hide
+     * attribute is enabled.
+     *
+     * @param field the field to check for the hide attribute
+     *
+     * @return true if the hide attribute is enabled, false otherwise
+     */
+    private boolean isDataFieldAttributeSecurityHide(Field field) {
+        if (field instanceof DataField) {
+            DataField dataField = (DataField) field;
+            DataFieldSecurity dataFieldSecurity = dataField.getDataFieldSecurity();
+
+            if (dataFieldSecurity == null) {
+                return false;
+            }
+
+            if (dataFieldSecurity.getAttributeSecurity() == null || !dataFieldSecurity.getAttributeSecurity().isHide()) {
+                return false;
+            }
+
+            return true;
+        } else {
+            return false;
+        }
+    }
+
     @BeanTagAttribute(name="configurationService",type= BeanTagAttribute.AttributeType.SINGLEBEAN)
     protected ConfigurationService getConfigurationService() {
         if (configurationService == null) {
@@ -619,4 +746,16 @@ public class ViewAuthorizerBase extends DataObjectAuthorizerBase implements View
         this.configurationService = configurationService;
     }
 
+    protected RequestAuthorizationCache getRequestAuthorizationCache() {
+        return requestAuthorizationCache;
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    public void setRequestAuthorizationCache(RequestAuthorizationCache requestAuthorizationCache) {
+        this.requestAuthorizationCache = requestAuthorizationCache;
+    }
+
 }
