@@ -16,8 +16,12 @@
 package edu.sampleu.demo.kitchensink;
 
 import org.kuali.rice.krad.service.KRADServiceLocatorWeb;
+import org.kuali.rice.krad.uif.UifConstants;
 import org.kuali.rice.krad.uif.UifParameters;
+import org.kuali.rice.krad.util.AuditCluster;
+import org.kuali.rice.krad.util.AuditError;
 import org.kuali.rice.krad.util.GlobalVariables;
+import org.kuali.rice.krad.util.KRADConstants;
 import org.kuali.rice.krad.web.controller.UifControllerBase;
 import org.kuali.rice.krad.web.form.UifFormBase;
 import org.springframework.stereotype.Controller;
@@ -29,9 +33,10 @@ import org.springframework.web.servlet.ModelAndView;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-import java.beans.PropertyEditor;
-import java.util.Map;
+import java.util.ArrayList;
+import java.util.List;
 import java.util.Properties;
+import java.util.Set;
 
 /**
  * Controller for the Test UI Page
@@ -46,14 +51,13 @@ public class UifComponentsTestController extends UifControllerBase {
      * @see org.kuali.rice.krad.web.controller.UifControllerBase#createInitialForm(javax.servlet.http.HttpServletRequest)
      */
     @Override
-    protected UifComponentsTestForm createInitialForm(HttpServletRequest request) {
+    protected UifComponentsTestForm createInitialForm() {
         return new UifComponentsTestForm();
     }
 
     @Override
     @RequestMapping(params = "methodToCall=start")
-    public ModelAndView start(@ModelAttribute("KualiForm") UifFormBase form, BindingResult result,
-            HttpServletRequest request, HttpServletResponse response) {
+    public ModelAndView start(UifFormBase form) {
         UifComponentsTestForm uiTestForm = (UifComponentsTestForm) form;
         form.setState("state1");
         //for generated view:
@@ -78,21 +82,22 @@ public class UifComponentsTestController extends UifControllerBase {
 
         GlobalVariables.getMessageMap().addGrowlMessage("Welcome!", "kitchenSink.welcome");
 
-        return super.start(uiTestForm, result, request, response);
+        return super.start(uiTestForm);
     }
 
     @RequestMapping(method = RequestMethod.POST, params = "methodToCall=save")
     public ModelAndView save(@ModelAttribute("KualiForm") UifComponentsTestForm uiTestForm, BindingResult result,
             HttpServletRequest request, HttpServletResponse response) {
         KRADServiceLocatorWeb.getViewValidationService().validateView(uiTestForm);
-        return getUIFModelAndView(uiTestForm);
+
+        return getModelAndView(uiTestForm);
     }
 
     @RequestMapping(method = RequestMethod.POST, params = "methodToCall=close")
     public ModelAndView close(@ModelAttribute("KualiForm") UifComponentsTestForm uiTestForm, BindingResult result,
             HttpServletRequest request, HttpServletResponse response) {
 
-        return getUIFModelAndView(uiTestForm, "UifCompView-Page1");
+        return getModelAndView(uiTestForm, "UifCompView-Page1");
     }
 
     /**
@@ -114,14 +119,14 @@ public class UifComponentsTestController extends UifControllerBase {
             GlobalVariables.getMessageMap().putInfo("gField3", "serverTestInfo");
         }
 
-        return getUIFModelAndView(form, pageId);
+        return getModelAndView(form, pageId);
     }
 
     @RequestMapping(method = RequestMethod.POST, params = "methodToCall=refreshProgGroup")
     public ModelAndView refreshProgGroup(@ModelAttribute("KualiForm") UifComponentsTestForm uiTestForm,
             BindingResult result, HttpServletRequest request, HttpServletResponse response) {
 
-        return getUIFModelAndView(uiTestForm);
+        return getModelAndView(uiTestForm);
     }
 
     @RequestMapping(method = RequestMethod.POST, params = "methodToCall=refreshWithServerMessages")
@@ -131,7 +136,7 @@ public class UifComponentsTestController extends UifControllerBase {
         GlobalVariables.getMessageMap().putWarning("field45", "serverTestWarning");
         GlobalVariables.getMessageMap().putInfo("field45", "serverTestInfo");
 
-        return getUIFModelAndView(uiTestForm);
+        return getModelAndView(uiTestForm);
     }
 
     @RequestMapping(method = RequestMethod.POST, params = "methodToCall=genCollectionServerMessages")
@@ -148,7 +153,7 @@ public class UifComponentsTestController extends UifControllerBase {
         GlobalVariables.getMessageMap().putError("list5[0].subList[0].field1", "serverTestError");
         GlobalVariables.getMessageMap().putWarning("list5[0].subList[0].field1", "serverTestWarning");
         GlobalVariables.getMessageMap().putInfo("list5[0].subList[0].field1", "serverTestInfo");
-        return refresh(uiTestForm, result, request, response);
+        return refresh(uiTestForm);
     }
 
     /**
@@ -158,26 +163,30 @@ public class UifComponentsTestController extends UifControllerBase {
     public ModelAndView addErrors(@ModelAttribute("KualiForm") UifFormBase form, BindingResult result,
             HttpServletRequest request, HttpServletResponse response) {
 
-        if (form.getPostedView().getCurrentPageId().equals("Demo-ValidationLayout-SectionsPageSectionMessages")) {
+        if (form.getPageId().equals("Demo-ValidationLayout-SectionsPageSectionMessages")) {
             GlobalVariables.getMessageMap().putError("Demo-ValidationLayout-Section1", "errorSectionTest");
             GlobalVariables.getMessageMap().putError("Demo-ValidationLayout-Section2", "errorSectionTest");
-        } else if (form.getPostedView().getCurrentPageId().equals("Demo-ValidationLayout-SectionsPageUnmatched")) {
+        } else if (form.getPageId().equals("Demo-ValidationLayout-SectionsPageUnmatched")) {
             GlobalVariables.getMessageMap().putError("badKey", "unmatchedTest");
-        } else if (form.getPostedView().getCurrentPageId().equals("Demo-ValidationLayout-SubSectionsPage")) {
+        } else if (form.getPageId().equals("Demo-ValidationLayout-SubSectionsPage")) {
             GlobalVariables.getMessageMap().putError("Uif-ValidationLayout-SubGroup", "errorSectionTest");
         }
 
-        if (form.getPostedView().getId().equals("RichMessagesView")) {
+        if (form.getViewPostMetadata().getId().equals("RichMessagesView")) {
             GlobalVariables.getMessageMap().putError("Demo-BasicMessagesSection", "richValidationMessageTest");
             GlobalVariables.getMessageMap().putError("field5", "richValidationMessageTest2");
         }
 
-        Map<String, PropertyEditor> propertyEditors = form.getPostedView().getViewIndex().getFieldPropertyEditors();
-        for (String key : propertyEditors.keySet()) {
-            GlobalVariables.getMessageMap().putError(key, "error1Test");
+        Set<String> inputFieldIds = form.getViewPostMetadata().getInputFieldIds();
+        for (String id : inputFieldIds) {
+            if (form.getViewPostMetadata().getComponentPostData(id, UifConstants.PostMetadata.PATH) != null) {
+                String key = (String) form.getViewPostMetadata().getComponentPostData(id,
+                        UifConstants.PostMetadata.PATH);
+                GlobalVariables.getMessageMap().putError(key, "error1Test");
+            }
         }
 
-        return getUIFModelAndView(form);
+        return getModelAndView(form);
     }
 
     /**
@@ -187,19 +196,23 @@ public class UifComponentsTestController extends UifControllerBase {
     public ModelAndView addWarnings(@ModelAttribute("KualiForm") UifFormBase form, BindingResult result,
             HttpServletRequest request, HttpServletResponse response) {
 
-        if (form.getPostedView().getCurrentPageId().equals("Demo-ValidationLayout-SectionsPageSectionMessages")) {
+        if (form.getPageId().equals("Demo-ValidationLayout-SectionsPageSectionMessages")) {
             GlobalVariables.getMessageMap().putWarning("Demo-ValidationLayout-Section1", "warningSectionTest");
             GlobalVariables.getMessageMap().putWarning("Demo-ValidationLayout-Section2", "warningSectionTest");
-        } else if (form.getPostedView().getCurrentPageId().equals("Demo-ValidationLayout-SectionsPageUnmatched")) {
+        } else if (form.getPageId().equals("Demo-ValidationLayout-SectionsPageUnmatched")) {
             GlobalVariables.getMessageMap().putWarning("badKey", "unmatchedTest");
         }
 
-        Map<String, PropertyEditor> propertyEditors = form.getPostedView().getViewIndex().getFieldPropertyEditors();
-        for (String key : propertyEditors.keySet()) {
-            GlobalVariables.getMessageMap().putWarning(key, "warning1Test");
+        Set<String> inputFieldIds = form.getViewPostMetadata().getInputFieldIds();
+        for (String id : inputFieldIds) {
+            if (form.getViewPostMetadata().getComponentPostData(id, UifConstants.PostMetadata.PATH) != null) {
+                String key = (String) form.getViewPostMetadata().getComponentPostData(id,
+                        UifConstants.PostMetadata.PATH);
+                GlobalVariables.getMessageMap().putWarning(key, "warning1Test");
+            }
         }
 
-        return getUIFModelAndView(form);
+        return getModelAndView(form);
     }
 
     /**
@@ -209,19 +222,23 @@ public class UifComponentsTestController extends UifControllerBase {
     public ModelAndView addInfo(@ModelAttribute("KualiForm") UifFormBase form, BindingResult result,
             HttpServletRequest request, HttpServletResponse response) {
 
-        if (form.getPostedView().getCurrentPageId().equals("Demo-ValidationLayout-SectionsPageSectionMessages")) {
+        if (form.getPageId().equals("Demo-ValidationLayout-SectionsPageSectionMessages")) {
             GlobalVariables.getMessageMap().putInfo("Demo-ValidationLayout-Section1", "infoSectionTest");
             GlobalVariables.getMessageMap().putInfo("Demo-ValidationLayout-Section2", "infoSectionTest");
-        } else if (form.getPostedView().getCurrentPageId().equals("Demo-ValidationLayout-SectionsPageUnmatched")) {
+        } else if (form.getPageId().equals("Demo-ValidationLayout-SectionsPageUnmatched")) {
             GlobalVariables.getMessageMap().putInfo("badKey", "unmatchedTest");
         }
 
-        Map<String, PropertyEditor> propertyEditors = form.getPostedView().getViewIndex().getFieldPropertyEditors();
-        for (String key : propertyEditors.keySet()) {
-            GlobalVariables.getMessageMap().putInfo(key, "info1Test");
+        Set<String> inputFieldIds = form.getViewPostMetadata().getInputFieldIds();
+        for (String id : inputFieldIds) {
+            if (form.getViewPostMetadata().getComponentPostData(id, UifConstants.PostMetadata.PATH) != null) {
+                String key = (String) form.getViewPostMetadata().getComponentPostData(id,
+                        UifConstants.PostMetadata.PATH);
+                GlobalVariables.getMessageMap().putInfo(key, "info1Test");
+            }
         }
 
-        return getUIFModelAndView(form);
+        return getModelAndView(form);
     }
 
     /**
@@ -235,7 +252,7 @@ public class UifComponentsTestController extends UifControllerBase {
         this.addWarnings(form, result, request, response);
         this.addInfo(form, result, request, response);
 
-        return getUIFModelAndView(form);
+        return getModelAndView(form);
     }
 
     /**
@@ -248,7 +265,7 @@ public class UifComponentsTestController extends UifControllerBase {
         this.addErrors(form, result, request, response);
         this.addWarnings(form, result, request, response);
 
-        return getUIFModelAndView(form);
+        return getModelAndView(form);
     }
 
     /**
@@ -261,7 +278,7 @@ public class UifComponentsTestController extends UifControllerBase {
         this.addErrors(form, result, request, response);
         this.addInfo(form, result, request, response);
 
-        return getUIFModelAndView(form);
+        return getModelAndView(form);
     }
 
     /**
@@ -271,13 +288,13 @@ public class UifComponentsTestController extends UifControllerBase {
     public ModelAndView addSingleErrorMessage(@ModelAttribute("KualiForm") UifFormBase form, BindingResult result,
             HttpServletRequest request, HttpServletResponse response) {
 
-        if (form.getPostedView().getCurrentPageId().equals("Demo-ValidationLayout-SubSectionsPage")) {
+        if (form.getPageId().equals("Demo-ValidationLayout-SubSectionsPage")) {
             GlobalVariables.getMessageMap().putError("Uif-ValidationLayout-SubGroup", "errorSectionTest");
         } else {
             GlobalVariables.getMessageMap().putError("Demo-ValidationLayout-Section1", "errorSectionTest");
         }
 
-        return getUIFModelAndView(form);
+        return getModelAndView(form);
     }
 
     /**
@@ -290,52 +307,76 @@ public class UifComponentsTestController extends UifControllerBase {
         this.addWarnings(form, result, request, response);
         this.addInfo(form, result, request, response);
 
-        return getUIFModelAndView(form);
+        return getModelAndView(form);
+    }
+
+    /**
+     * Adds warning and info messages to fields defined in the validationMessageFields array
+     */
+    @RequestMapping(method = RequestMethod.POST, params = "methodToCall=addAuditErrors")
+    public ModelAndView addAuditErrors(@ModelAttribute("KualiForm") UifFormBase form, BindingResult result,
+            HttpServletRequest request, HttpServletResponse response) {
+
+        List<AuditError> auditErrors = new ArrayList<AuditError>();
+        List<AuditError> auditWarnings = new ArrayList<AuditError>();
+        Set<String> inputFieldIds = form.getViewPostMetadata().getInputFieldIds();
+        for (String id : inputFieldIds) {
+            if (form.getViewPostMetadata().getComponentPostData(id, UifConstants.PostMetadata.PATH) != null) {
+                String key = (String) form.getViewPostMetadata().getComponentPostData(id,
+                        UifConstants.PostMetadata.PATH);
+                auditErrors.add(new AuditError(key, "error1Test", "link"));
+                auditWarnings.add(new AuditError(key, "warning1Test", "link"));
+            }
+        }
+        auditErrors.add(new AuditError("Demo-ValidationLayout-Section1", "errorSectionTest", "link"));
+
+        GlobalVariables.getAuditErrorMap().put("A", new AuditCluster("A", auditErrors,
+                KRADConstants.Audit.AUDIT_ERRORS));
+        GlobalVariables.getAuditErrorMap().put("B", new AuditCluster("B", auditWarnings,
+                KRADConstants.Audit.AUDIT_WARNINGS));
+
+        return getModelAndView(form);
     }
 
     @RequestMapping(method = RequestMethod.POST, params = "methodToCall=gotoState2")
     public ModelAndView gotoState2(@ModelAttribute("KualiForm") UifFormBase form, BindingResult result,
             HttpServletRequest request, HttpServletResponse response) {
 
-        KRADServiceLocatorWeb.getViewValidationService().validateView(form.getPostedView(), form, "state2");
+        KRADServiceLocatorWeb.getViewValidationService().validateView(form, "state2");
         if (!GlobalVariables.getMessageMap().hasErrors()) {
             form.setState("state2");
         }
 
-        return getUIFModelAndView(form);
+        return getModelAndView(form);
     }
 
     @RequestMapping(method = RequestMethod.POST, params = "methodToCall=gotoState3")
     public ModelAndView gotoState3(@ModelAttribute("KualiForm") UifFormBase form, BindingResult result,
             HttpServletRequest request, HttpServletResponse response) {
 
-        KRADServiceLocatorWeb.getViewValidationService().validateView(form.getPostedView(), form, "state3");
+        KRADServiceLocatorWeb.getViewValidationService().validateView(form, "state3");
         if (!GlobalVariables.getMessageMap().hasErrors()) {
             form.setState("state3");
         }
 
-        return getUIFModelAndView(form);
+        return getModelAndView(form);
     }
 
     @RequestMapping(method = RequestMethod.POST, params = "methodToCall=gotoState4")
     public ModelAndView gotoState4(@ModelAttribute("KualiForm") UifFormBase form, BindingResult result,
             HttpServletRequest request, HttpServletResponse response) {
 
-        KRADServiceLocatorWeb.getViewValidationService().validateView(form.getPostedView(), form, "state4");
+        KRADServiceLocatorWeb.getViewValidationService().validateView(form, "state4");
         if (!GlobalVariables.getMessageMap().hasErrors()) {
             form.setState("state4");
         }
 
-        return getUIFModelAndView(form);
+        return getModelAndView(form);
     }
 
     /**
      * Generates a fake incident report to test for errorCallback
      *
-     * @param form
-     * @param result
-     * @param request
-     * @param response
      * @return ModelAndView model and view
      */
     @RequestMapping(method = RequestMethod.POST, params = "methodToCall=errorCheck")
@@ -346,16 +387,12 @@ public class UifComponentsTestController extends UifControllerBase {
             throw new RuntimeException("Generate fake incident report");
         }
 
-        return getUIFModelAndView(form);
+        return getModelAndView(form);
     }
 
     /**
      * Test controller method to check for ajax redirect functionality. Redirects to the portal main page
      *
-     * @param form
-     * @param result
-     * @param request
-     * @param response
      * @return ModelAndView model and view
      */
     @RequestMapping(method = RequestMethod.POST, params = "methodToCall=redirectCheck")
@@ -368,16 +405,15 @@ public class UifComponentsTestController extends UifControllerBase {
     }
 
     @Override
-    public ModelAndView addLine(@ModelAttribute("KualiForm") UifFormBase uifForm, BindingResult result,
-            HttpServletRequest request, HttpServletResponse response) {
+    public ModelAndView addLine(UifFormBase uifForm) {
         GlobalVariables.getMessageMap().addGrowlMessage("Greetings!", "kitchenSink.welcome");
-        if (uifForm.getPostedView().getCurrentPageId().equals("Demo-ValidationLayout-CollectionsErrorPage")) {
+        if (uifForm.getPageId().equals("Demo-ValidationLayout-CollectionsErrorPage")) {
             GlobalVariables.getMessageMap().putError("Demo-ValidationLayout-CollectionErrorSection",
                     "errorSectionTest");
             GlobalVariables.getMessageMap().putErrorForSectionId("Demo-ValidationLayout-CollectionErrorSection",
                     "errorSectionTest");
         }
-        return super.addLine(uifForm, result, request, response);
+        return super.addLine(uifForm);
     }
 
     @RequestMapping(method = RequestMethod.POST, params = "methodToCall=customLineAction")
@@ -390,17 +426,12 @@ public class UifComponentsTestController extends UifControllerBase {
         GlobalVariables.getMessageMap().addGrowlMessage("Action Parameters", "actionParms.message", actionParm1,
                 actionParm2);
 
-        return super.deleteLine(uifForm, result, request, response);
+        return super.deleteLine(uifForm);
     }
 
     /**
      * Performs custom line action for collection 4 in kitchen sink collection demo.
      * Just puts out a growl message and returns.
-     * @param uifForm
-     * @param result
-     * @param request
-     * @param response
-     * @return
      */
     @RequestMapping(method = RequestMethod.POST, params = "methodToCall=updateOfficial")
     public ModelAndView updateOfficial(@ModelAttribute("KualiForm") UifFormBase uifForm, BindingResult result,
@@ -410,16 +441,12 @@ public class UifComponentsTestController extends UifControllerBase {
 
         GlobalVariables.getMessageMap().addGrowlMessage("Action Parameters", "customLineAction.message", actionParm1);
 
-        return getUIFModelAndView(uifForm);
+        return getModelAndView(uifForm);
     }
 
     /**
      * Changes the view to readOnly and returns.
      *
-     * @param uifForm
-     * @param result
-     * @param request
-     * @param response
      * @return readOnly View
      */
     @RequestMapping(method = RequestMethod.POST, params = "methodToCall=makeReadOnly")
@@ -427,6 +454,6 @@ public class UifComponentsTestController extends UifControllerBase {
             HttpServletRequest request, HttpServletResponse response) {
         //set View to readOnly
         uifForm.getView().setReadOnly(true);
-        return getUIFModelAndView(uifForm);
+        return getModelAndView(uifForm);
     }
 }
