@@ -14,10 +14,4 @@
 -- limitations under the License.
 --
 
-drop table krew_ria_doc_t;
-drop table krew_ria_doctype_map_id_s;
-drop table krew_ria_doctype_map_t;
-
-drop table krew_rmv_rplc_doc_t;
-drop table krew_rmv_rplc_grp_t;
-drop table krew_rmv_rplc_rule_t;
\ No newline at end of file
+ALTER TABLE KREW_INIT_RTE_NODE_INSTN_T CHANGE RTE_NODE_INSTN_ID RTE_NODE_INSTN_ID VARCHAR(40);
\ No newline at end of file
