@@ -14,5 +14,11 @@
 -- limitations under the License.
 --
 
--- Drop foreign key constraint on krms_prop_t table
-alter table KRMS_PROP_T drop foreign key krms_prop_fk1;
+
+--
+--     KULRICE-6676 - adding system parameter for default locale
+--
+
+INSERT INTO KRCR_PARM_T VALUES ('KR-NS', 'All', 'DEFAULT_LOCALE_CODE', uuid(), 1, 'CONFG', 'en-US',
+'The locale code that should be used within the application when otherwise not specified.', 'A', 'KUALI')
+;
